@@ -1,10 +1,11 @@
 from packtivity.asyncbackends import PacktivityProxyBase
-from packtivity.typedleafs import TypedLeafs
+from packtivity import datamodel as _datamodel
+
 
 class TrivialProxy(PacktivityProxyBase):
-    '''
+    """
     A trivial proxy that carries the results and status already
-    '''
+    """
 
     def __init__(self, status, resultdata, datamodel):
         self.status = status
@@ -12,30 +13,33 @@ class TrivialProxy(PacktivityProxyBase):
         self.datamodel = datamodel
 
     def proxyname(self):
-        return 'TrivialProxy'
+        return "TrivialProxy"
 
     def details(self):
         return {
-            'resultdata':self.resultdata,
-            'datamodel': self.datamodel,
-            'status':self.status
+            "resultdata": self.resultdata,
+            "datamodel": self.datamodel,
+            "status": self.status,
         }
 
     @classmethod
-    def fromJSON(cls,data):
-        return cls(**data['proxydetails'])
+    def fromJSON(cls, data):
+        return cls(**data["proxydetails"])
+
 
 class TrivialBackend(object):
-    '''
+    """
     A trivial backend that can only return proxy based information, no submission
-    '''
+    """
+
+    def __init__(self):
+        self.datamodel = _datamodel
 
     def submit(self, task):
-        raise NotImplementedError(
-            'The trivial proxy is not made for submission')
+        raise NotImplementedError("The trivial proxy is not made for submission")
 
     def result(self, resultproxy):
-        return TypedLeafs(resultproxy.resultdata, resultproxy.datamodel)
+        return self.datamodel.create(resultproxy.resultdata, resultproxy.datamodel)
 
     def expected_result(self, resultproxy):
         return None
@@ -45,7 +49,7 @@ class TrivialBackend(object):
         return True
 
     def successful(self, resultproxy):
-        return resultproxy.status == 'SUCCESS'
+        return resultproxy.status == "SUCCESS"
 
     def fail_info(self, resultproxy):
         return None
